@@ -1,101 +1,99 @@
 import argparse
 import json
 from argparse import Namespace
-from typing import Dict, Union
+from dataclasses import dataclass
+from typing import Dict, Generic, TypeVar
 
-from mindee import Client
-from mindee.documents.base import serialize_for_json
+from mindee import Client, PageOptions, documents
+from mindee.client import DocumentClient
+from mindee.documents.base import Document, serialize_for_json
 
-DOCUMENTS: Dict[str, Dict[str, Union[list, str]]] = {
-    "invoice": {
-        "help": "Invoice",
-        "required_keys": ["invoice"],
-        "doc_type": "invoice",
-    },
-    "receipt": {
-        "help": "Expense Receipt",
-        "required_keys": ["receipt"],
-        "doc_type": "receipt",
-    },
-    "passport": {
-        "help": "Passport",
-        "required_keys": ["passport"],
-        "doc_type": "passport",
-    },
-    "financial": {
-        "help": "Financial Document (receipt or invoice)",
-        "required_keys": ["invoice", "receipt"],
-        "doc_type": "financial_doc",
-    },
-    "custom": {
-        "help": "Custom document type from API builder",
-    },
+TypeDoc = TypeVar("TypeDoc", bound=Document)
+
+
+@dataclass
+class CommandConfig(Generic[TypeDoc]):
+    help: str
+    doc_class: TypeDoc
+
+
+DOCUMENTS: Dict[str, CommandConfig] = {
+    "custom": CommandConfig(
+        help="Custom document type from API builder",
+        doc_class=documents.TypeCustomV1,
+    ),
+    "invoice": CommandConfig(
+        help="Invoice",
+        doc_class=documents.TypeInvoiceV4,
+    ),
+    "receipt": CommandConfig(
+        help="Expense Receipt",
+        doc_class=documents.TypeReceiptV4,
+    ),
+    "passport": CommandConfig(
+        help="Passport",
+        doc_class=documents.TypePassportV1,
+    ),
+    "financial": CommandConfig(
+        help="Financial Document (receipt or invoice)",
+        doc_class=documents.TypeFinancialV1,
+    ),
+    "us-check": CommandConfig(
+        help="US Bank Check",
+        doc_class=documents.us.TypeBankCheckV1,
+    ),
 }
 
 
-def _ots_client(args: Namespace, info: dict):
-    client = Client(raise_on_error=args.raise_on_error)
-    kwargs = {}
-    if len(info["required_keys"]) > 1:
-        for key in info["required_keys"]:
-            kwargs["%s_api_key" % key] = getattr(args, f"{key}_api_key")
-    else:
-        kwargs["api_key"] = getattr(args, "%s_api_key" % args.product_name)
-    func = getattr(client, f"config_{info['doc_type']}")
-    func(**kwargs)
-    return client
-
-
-def _custom_client(args: Namespace):
-    client = Client(raise_on_error=args.raise_on_error)
-    client.config_custom_doc(
-        document_type=args.doc_type,
-        singular_name=args.doc_type,
-        plural_name=args.doc_type + "s",
-        account_name=args.username,
-        api_key=args.api_key,
-    )
-    return client
+def _get_input_doc(client, args) -> DocumentClient:
+    if args.input_type == "file":
+        with open(args.path, "rb", buffering=30) as file_handle:
+            return client.doc_from_file(file_handle)
+    elif args.input_type == "base64":
+        with open(args.path, "rt", encoding="ascii") as base64_handle:
+            return client.doc_from_b64string(base64_handle.read(), "test.jpg")
+    elif args.input_type == "bytes":
+        with open(args.path, "rb") as bytes_handle:
+            return client.doc_from_bytes(bytes_handle.read(), bytes_handle.name)
+    return client.doc_from_path(args.path)
 
 
 def call_endpoint(args: Namespace):
     """Call the endpoint given passed arguments."""
+    client = Client(api_key=args.api_key, raise_on_error=args.raise_on_error)
     if args.product_name == "custom":
-        client = _custom_client(args)
-        doc_type = args.doc_type
-    else:
-        info = DOCUMENTS[args.product_name]
-        client = _ots_client(args, info)
-        doc_type = info["doc_type"]
+        client.add_endpoint(
+            endpoint_name=args.doc_type,
+            account_name=args.username,
+        )
+    info = DOCUMENTS[args.product_name]
+    doc_class = info.doc_class
 
-    if args.input_type == "file":
-        with open(args.path, "rb", buffering=30) as file_handle:
-            doc_to_parse = client.doc_from_file(file_handle, cut_pdf=args.cut_pdf)
-    elif args.input_type == "base64":
-        with open(args.path, "rt", encoding="ascii") as base64_handle:
-            doc_to_parse = client.doc_from_b64string(
-                base64_handle.read(), "test.jpg", cut_pdf=args.cut_pdf
-            )
-    elif args.input_type == "bytes":
-        with open(args.path, "rb") as bytes_handle:
-            doc_to_parse = client.doc_from_bytes(
-                bytes_handle.read(), bytes_handle.name, cut_pdf=args.cut_pdf
-            )
-    else:
-        doc_to_parse = client.doc_from_path(args.path, cut_pdf=args.cut_pdf)
+    input_doc = _get_input_doc(client, args)
 
+    if args.cut_doc and args.doc_pages:
+        page_options = PageOptions(range(args.doc_pages), on_min_pages=0)
+    else:
+        page_options = None
     if args.product_name == "custom":
-        parsed_data = doc_to_parse.parse(doc_type, username=args.username)
+        parsed_data = input_doc.parse(
+            doc_class,
+            endpoint_name=args.doc_type,
+            account_name=args.username,
+            page_options=page_options,
+        )
     else:
-        parsed_data = doc_to_parse.parse(doc_type, include_words=args.include_words)
+        parsed_data = input_doc.parse(
+            doc_class, include_words=args.include_words, page_options=page_options
+        )
 
     if args.output_type == "raw":
         print(json.dumps(parsed_data.http_response, indent=2))
     elif args.output_type == "parsed":
-        doc = getattr(parsed_data, doc_type)
+        doc = parsed_data.document
         print(json.dumps(doc, indent=2, default=serialize_for_json))
     else:
-        print(getattr(parsed_data, doc_type))
+        print(parsed_data.document)
 
 
 def _parse_args() -> Namespace:
@@ -113,12 +111,13 @@ def _parse_args() -> Namespace:
         required=True,
     )
     for name, info in DOCUMENTS.items():
-        subp = subparsers.add_parser(name, help=info["help"])
+        subp = subparsers.add_parser(name, help=info.help)
         if name == "custom":
             subp.add_argument(
                 "-u",
                 "--user",
                 dest="username",
+                required=True,
                 help="API account name for the endpoint",
             )
             subp.add_argument(
@@ -129,12 +128,12 @@ def _parse_args() -> Namespace:
             )
             subp.add_argument(dest="doc_type", help="Document type")
         else:
-            for key_name in info["required_keys"]:
-                subp.add_argument(
-                    f"--{key_name}-key",
-                    dest=f"{key_name}_api_key",
-                    help=f"API key for {key_name} document endpoint",
-                )
+            subp.add_argument(
+                "-k",
+                "--key",
+                dest="api_key",
+                help="API key for the endpoint",
+            )
             subp.add_argument(
                 "-w",
                 "--with-words",
@@ -166,20 +165,19 @@ def _parse_args() -> Namespace:
             "- parsed: the validated and parsed data fields\n",
         )
         subp.add_argument(
-            "-C",
-            "--no-cut-pdf",
-            dest="cut_pdf",
-            action="store_false",
-            help="Don't cut document pages",
+            "-c",
+            "--cut",
+            dest="cut_doc",
+            action="store_true",
+            help="Cut document pages",
         )
         subp.add_argument(
             "-p",
-            "--pdf-pages",
-            dest="pdf_pages",
+            "--pages-keep",
+            dest="doc_pages",
             type=int,
-            default=3,
-            choices=[1, 2, 3],
-            help="Number of document pages to cut by, default: 3",
+            default=5,
+            help="Number of document pages to keep, default: 5",
         )
         subp.add_argument(dest="path", help="Full path to the file")
 
