@@ -1,34 +1,34 @@
 from typing import Optional
 
-from mindee.fields.base import Field
+from mindee.fields.base import BaseField, FieldPositionMixin, TypePrediction
 
 
-class Amount(Field):
+class AmountField(FieldPositionMixin, BaseField):
     value: Optional[float] = None
 
     def __init__(
         self,
-        amount_prediction: dict,
-        value_key: str = "amount",
+        prediction: TypePrediction,
         reconstructed: bool = False,
         page_n: Optional[int] = None,
     ):
         """
         Amount field object.
 
-        :param amount_prediction: Amount prediction object from HTTP response
-        :param value_key: Key to use in the amount_prediction dict
+        :param prediction: Amount prediction object from HTTP response
         :param reconstructed: Bool for reconstructed object (not extracted in the API)
-        :param page_n: Page number for multi-page PDF
+        :param page_n: Page number for multi-page document
         """
         super().__init__(
-            amount_prediction,
-            value_key=value_key,
+            prediction,
+            value_key="value",
             reconstructed=reconstructed,
             page_n=page_n,
         )
         try:
-            self.value = round(float(amount_prediction[value_key]), 3)
+            self.value = round(float(prediction["value"]), 3)
         except (ValueError, TypeError, KeyError):
             self.value = None
             self.confidence = 0.0
+
+        self._set_position(prediction)
